pub fn run_simulation<T: MosaikApi>(
addr: ConnectionDirection,
simulator: T,
) -> Result<(), Box<dyn Error + Send + Sync>>Expand description
Main calls this function with the simulator that should run and the direction with an address for the connection to mosaik.