pub enum SimulatorType {
TimeBased,
EventBased,
Hybrid,
}Expand description
The three types of simulators. With Hybrid being the default.
TimeBased: start at time 0, return the next step time after each step, and produce data valid for ([t_{now}, t_{next})).EventBased: start whenever their first event is scheduled, step at event times, can schedule their own events, and produce output valid at specific times.Hybrid: a mix of the two. Also starts at time 0.
Variants