Meta

Struct Meta 

pub struct Meta {
    pub simulator_type: SimulatorType,
    pub models: HashMap<ModelName, ModelDescription>,
    pub extra_methods: Option<Vec<String>>,
    /* private fields */
}
The meta-data for a simulator.

Fields

simulator_type: SimulatorType

The simulator’s stepping type.

models: HashMap<ModelName, ModelDescription>

The descriptions of this simulator’s models.

extra_methods: Option<Vec<String>>

The names of the extra methods this simulator supports.

Note

These methods can be called while the scenario is being created and can be used for operations that don’t really belong into init() or create().

Implementations

Source

impl Meta

pub fn new( simulator_type: SimulatorType, models: HashMap<ModelName, ModelDescription>, extra_methods: Option<Vec<String>>, ) -> Self

pub fn version(&self) -> &str