pub enum ConnectionDirection {
ConnectToAddress(SocketAddr),
ListenOnAddress(SocketAddr),
}Expand description
The direction of the connection with the address of the socket.
Either we listen on an address or we connect to an address.
This is used in the run_simulation function.
Variants
ConnectToAddress(SocketAddr)
ListenOnAddress(SocketAddr)