CreateResult

Struct CreateResult 

pub struct CreateResult {
    pub eid: EntityId,
    pub model_type: ModelName,
    pub rel: Option<Vec<EntityId>>,
    pub children: Option<Vec<CreateResult>>,
    pub extra_info: Option<HashMap<String, String>>,
}
The type for elements of the list returned by create calls in the mosaik API.

Fields

eid: EntityId

The entity ID of this entity.

model_type: ModelName

The model name (as given in the simulator’s meta) of this entity.

rel: Option<Vec<EntityId>>

The entity IDs of the entities of this simulator that are related to this entity.

children: Option<Vec<CreateResult>>

The child entities of this entity.

extra_info: Option<HashMap<String, String>>

Any additional information about the entity that the simulator wants to pass back to the scenario.

Implementations

Source

impl CreateResult

pub fn new(eid: EntityId, model_type: ModelName) -> Self