pub struct ModelDescription {
pub public: bool,
pub params: &'static [&'static str],
pub attrs: &'static [&'static str],
pub any_inputs: Option<bool>,
pub trigger: Option<&'static [&'static str]>,
pub persistent: Option<&'static [&'static str]>,
}Expand description
Description of a single model in Meta
Example implementation
use mosaik_api::types::ModelDescription;
const foo: ModelDescription = ModelDescription {
public: true,
params: &["init_val"],
attrs: &["delta", "val"],
trigger: Some(&["delta"]),
any_inputs: None,
persistent: None,
};Fields
public: boolWhether the model can be created directly.
params: &'static [&'static str]The parameters given during creating of this model.
attrs: &'static [&'static str]The input and output attributes of this model.
any_inputs: Option<bool>Whether this model accepts inputs other than those specified in attrs.
trigger: Option<&'static [&'static str]>The input attributes that trigger a step of the associated simulator. (Non-trigger attributes are collected and supplied to the simulator when it steps next.)
persistent: Option<&'static [&'static str]>The output attributes that are persistent.
Implementations